/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { FormData, Blob, Request, Response, BaseApiCore, constructUrl, executeHttpCall } from '@managed-api/commons-core';
import { constructHeaders, errorMessageBuilder } from './common';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
export class JSMOnPremiseAssetsApiCore extends BaseApiCore {
    constructor(options) {
        super();
        this.options = options;
        if (!this.options?.errorStrategy && this.options?.errorStrategy !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Attachment = new AttachmentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Comment = new CommentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Icon = new IconGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Import = new ImportGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Index = new IndexGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Aql = new AqlGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Object = new ObjectGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Progress = new ProgressGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.QRCode = new QRCodeGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Config = new ConfigGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Attachment, this.Comment, this.Icon, this.Import, this.Index, this.Aql, this.Object, this.Progress, this.QRCode, this.Config);
    }
    setGlobalErrorStrategy(errorStrategy) {
        this.options = {
            ...this.options ?? {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        return this.options?.errorStrategy;
    }
}
class AllGroup {
    constructor(Attachment, Comment, Icon, Import, Index, Aql, Object, Progress, QRCode, Config) {
        this.Attachment = Attachment;
        this.Comment = Comment;
        this.Icon = Icon;
        this.Import = Import;
        this.Index = Index;
        this.Aql = Aql;
        this.Object = Object;
        this.Progress = Progress;
        this.QRCode = QRCode;
        this.Config = Config;
    }
    /**
     * Get object attachments
     * Alternative usage: Attachments.getAttachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__get
     * @param options Request options.
     */
    async getAttachments(options) {
        return this.Attachment.getAttachments(options);
    }
    /**
     * Create object attachments
     * Alternative usage: Attachments.createAttachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__post
     * @param options Request options.
     */
    async createAttachments(options) {
        return this.Attachment.createAttachments(options);
    }
    /**
     * Delete object attachment
     * Alternative usage: Attachments.deleteAttachment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments__attachmentid__delete
     * @param options Request options.
     */
    async deleteAttachment(options) {
        return this.Attachment.deleteAttachment(options);
    }
    /**
     * Create comments on objects
     * Alternative usage: Attachments.createComment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_create_post
     * @param options Request options.
     */
    async createComment(options) {
        return this.Comment.createComment(options);
    }
    /**
     * Get comments on objects
     * Alternative usage: Attachments.getComment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_object__objectid__get
     * @param options Request options.
     */
    async getComments(options) {
        return this.Comment.getComments(options);
    }
    /**
     * Load a single icon by id
     * Alternative usage: Icon.getIcon
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon__id__get
     * @param options Request options.
     */
    async getIcon(options) {
        return this.Icon.getIcon(options);
    }
    /**
     * Get all existing global icons
     * Alternative usage: Icon.getGlobalIcons
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_global_get
     * @param options Request options.
     */
    async getGlobalIcons(options) {
        return this.Icon.getGlobalIcons(options);
    }
    /**
     * Fetch all configured icons from the object schema
     * Alternative usage: Icon.getIconsBySchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_objectschema__objectschemaid__get
     * @param options Request options.
     */
    async getIconsBySchema(options) {
        return this.Icon.getIconsBySchema(options);
    }
    /**
     * Start import
     * Alternative usage: Import.startImport
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#import_start__id__post
     * @param options Request options.
     */
    async startImport(options) {
        return this.Import.startImport(options);
    }
    /**
     * Handle the indexing of Assets
     * Alternative usage: Import.startReindex
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_start_post
     * @param options Request options.
     */
    async startReindex(options) {
        return this.Index.startReindex(options);
    }
    /**
     * Only applicable in a Data Center environment. Resource to start a re-index of the current node. This reindex will not clean the entire cluster just refresh the objects in cache on the current data center node
     * Alternative usage: Import.startCurrentModeReindex
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_currentnode_post
     * @param options Request options.
     */
    async startCurrentModeReindex(options) {
        return this.Index.startCurrentModeReindex(options);
    }
    /**
     * Get objects
     * Alternative usage: Aql.getObjects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#aql_objects_get
     * @param options Request options.
     */
    async getObjects(options) {
        return this.Aql.getObjects(options);
    }
    /**
     * Get ongoing Assets processes
     * Alternative usage: Progress.getReindexProgress
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_assets_reindex_reindex_get
     * @param options Request options.
     */
    async getReindexProgress(options) {
        return this.Progress.getReindexProgress(options);
    }
    /**
     * Get progress for import source
     * Alternative usage: Progress.getImportProgress
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_imports__id__get
     * @param options Request options.
     */
    async getImportProgress(options) {
        return this.Progress.getImportProgress(options);
    }
    /**
     * Get QR code for object
     * Alternative usage: QRCode.getQrCode
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#qrcode_object__objectid__code_png_get
     * @param options Request options.
     */
    async getQrCode(options) {
        return this.QRCode.getQrCode(options);
    }
    /**
     * Get the Assets statuses
     * Alternative usage: Config.getConfigStatuses
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_get
     * @param options Request options.
     */
    async getConfigStatuses(options) {
        return this.Config.getConfigStatuses(options);
    }
    /**
     * Create status
     * Alternative usage: Config.createConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_post
     * @param options Request options.
     */
    async createConfigStatus(options) {
        return this.Config.createConfigStatus(options);
    }
    /**
     * Get status
     * Alternative usage: Config.getConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__get
     * @param options Request options.
     */
    async getConfigStatus(options) {
        return this.Config.getConfigStatus(options);
    }
    /**
     * Update status
     * Alternative usage: Config.updateConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__put
     * @param options Request options.
     */
    async updateConfigStatus(options) {
        return this.Config.updateConfigStatus(options);
    }
    /**
     * Delete status
     * Alternative usage: Config.deleteConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__delete
     * @param options Request options.
     */
    async deleteConfigStatus(options) {
        return this.Config.deleteConfigStatus(options);
    }
    /**
     * Load one object
     * Alternative usage: Object.getObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__get
     * @param options Request options.
     */
    async getObject(options) {
        return this.Object.getObject(options);
    }
    /**
     * Update an existing object in Assets
     * Alternative usage: Object.updateObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__put
     * @param options Request options.
     */
    async updateObject(options) {
        return this.Object.updateObject(options);
    }
    /**
     * Delete the referenced object
     * Alternative usage: Object.deleteObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__delete
     * @param options Request options.
     */
    async deleteObject(options) {
        return this.Object.deleteObject(options);
    }
    /**
     * Create a new object in Assets
     * Alternative usage: Object.createObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_create_post
     * @param options Request options.
     */
    async createObject(options) {
        return this.Object.createObject(options);
    }
    /**
     * Retrieve a list of objects based on an AQL.
     * Alternative usage: Object.getObjectsWithAql
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_navlist_aql_post
     * @param options Request options.
     */
    async getObjectsWithAql(options) {
        return this.Object.getObjectsWithAql(options);
    }
    /**
     * List all attributes for the given object
     * Alternative usage: Object.Attribute.getAttributes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__attributes_get
     * @param options Request options.
     */
    async getObjectAttributes(options) {
        return this.Object.Attribute.getAttributes(options);
    }
    /**
     * Creates a new attribute for a given attribute.
     * Alternative usage: Object.Attribute.createAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute_create_post
     * @param options Request options.
     */
    async createObjectAttribute(options) {
        return this.Object.Attribute.createAttribute(options);
    }
    /**
     * Update an already existing object attribute
     * Alternative usage: Object.Attribute.updateAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__put
     * @param options Request options.
     */
    async updateObjectAttribute(options) {
        return this.Object.Attribute.updateAttribute(options);
    }
    /**
     * Load a single object attribute
     * Alternative usage: Object.Attribute.getAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__get
     * @param options Request options.
     */
    async getObjectAttribute(options) {
        return this.Object.Attribute.getAttribute(options);
    }
    /**
     * Retrieve the history entries for this object
     * Alternative usage: Object.History.getHistory
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__history_get
     * @param options Request options.
     */
    async getObjectHistory(options) {
        return this.Object.History.getHistory(options);
    }
    /**
     * Find all references for an object
     * Alternative usage: Object.Reference.getReferences
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__referenceinfo_get
     * @param options Request options.
     */
    async getObjectReferences(options) {
        return this.Object.Reference.getReferences(options);
    }
    /**
     * Relation between Jira issues and Assets objects
     * Alternative usage: Object.Ticket.getConnectedTickets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectconnectedtickets__objectid__get
     * @param options Request options.
     */
    async getObjectConnectedTickets(options) {
        return this.Object.Ticket.getConnectedTickets(options);
    }
    /**
     * Resource to find object schemas in Assets
     * Alternative usage: Object.Schema.getSchemas
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_list_get
     * @param options Request options.
     */
    async getObjectSchemas(options) {
        return this.Object.Schema.getSchemas(options);
    }
    /**
     * Create schema
     * Alternative usage: Object.Schema.createSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_create_post
     * @param options Request options.
     */
    async createObjectSchema(options) {
        return this.Object.Schema.createSchema(options);
    }
    /**
     * Update schema
     * Alternative usage: Object.Schema.updateSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__put
     * @param options Request options.
     */
    async updateObjectSchema(options) {
        return this.Object.Schema.updateSchema(options);
    }
    /**
     * Get schema
     * Alternative usage: Object.Schema.getSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__get
     * @param options Request options.
     */
    async getObjectSchema(options) {
        return this.Object.Schema.getSchema(options);
    }
    /**
     * Delete schema
     * Alternative usage: Object.Schema.deleteSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__delete
     * @param options Request options.
     */
    async deleteObjectSchema(options) {
        return this.Object.Schema.deleteSchema(options);
    }
    /**
     * Find all object type attributes for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypeAttributes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__attributes_get
     * @param options Request options.
     */
    async getObjectSchemaObjectTypeAttributes(options) {
        return this.Object.Schema.getSchemaObjectTypeAttributes(options);
    }
    /**
     * Find all object types for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__objecttypes_flat_get
     * @param options Request options.
     */
    async getObjectSchemaObjectTypes(options) {
        return this.Object.Schema.getSchemaObjectTypes(options);
    }
    /**
     * Resource to get object type
     * Alternative usage: Object.Type.getType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__get
     * @param options Request options.
     */
    async getObjectType(options) {
        return this.Object.Type.getType(options);
    }
    /**
     * Update the object type
     * Alternative usage: Object.Type.updateType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__put
     * @param options Request options.
     */
    async updateObjectType(options) {
        return this.Object.Type.updateType(options);
    }
    /**
     * Delete the object type
     * Alternative usage: Object.Type.deleteType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__delete
     * @param options Request options.
     */
    async deleteObjectType(options) {
        return this.Object.Type.deleteType(options);
    }
    /**
     * Find all object type attribute for this object type
     * Alternative usage: Object.Type.getTypeAttributes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__attributes_get
     * @param options Request options.
     */
    async getObjectTypeAttributes(options) {
        return this.Object.Type.getTypeAttributes(options);
    }
    /**
     * Change position of this object type
     * Alternative usage: Object.Type.changeTypePosition
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__position_post
     * @param options Request options.
     */
    async changeObjectTypePosition(options) {
        return this.Object.Type.changeTypePosition(options);
    }
    /**
     * Create object type
     * Alternative usage: Object.Type.createType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype_create_post
     * @param options Request options.
     */
    async createObjectType(options) {
        return this.Object.Type.createType(options);
    }
    /**
     * Create object type attribute
     * Alternative usage: Object.Type.Attribute.createAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid__post
     * @param options Request options.
     */
    async createObjectTypeAttribute(options) {
        return this.Object.Type.Attribute.createAttribute(options);
    }
    /**
     * Update object type attribute
     * Alternative usage: Object.Type.Attribute.updateAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid___id__put
     * @param options Request options.
     */
    async updateObjectTypeAttribute(options) {
        return this.Object.Type.Attribute.updateAttribute(options);
    }
    /**
     * Delete object type attribute
     * Alternative usage: Object.Type.Attribute.deleteAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__id__delete
     * @param options Request options.
     */
    async deleteObjectTypeAttribute(options) {
        return this.Object.Type.Attribute.deleteAttribute(options);
    }
}
class AttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get object attachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__get
     * @param options Request options.
     */
    async getAttachments(options) {
        const { objectId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/attachments/object/${encodeURIComponent(objectId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create object attachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__post
     * @param options Request options.
     */
    async createAttachments(options) {
        const { objectId, body, headers, errorStrategy } = options;
        const formBody = new FormData();
        formBody.setBufferImplementation(this.implementation);
        body.forEach(x => {
            formBody.append('file', new Blob(this.implementation, [x.content], {}), x.fileName);
        });
        const bodyBlob = formBody.getBlob();
        const request = new Request('POST', `/rest/assets/latest/attachments/object/${encodeURIComponent(objectId)}`, constructHeaders(bodyBlob, headers), bodyBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete object attachment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments__attachmentid__delete
     * @param options Request options.
     */
    async deleteAttachment(options) {
        const { attachmentId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/attachments/${encodeURIComponent(attachmentId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class CommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Create comments on objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_create_post
     * @param options Request options.
     */
    async createComment(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/assets/latest/comment/create', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get comments on objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_object__objectid__get
     * @param options Request options.
     */
    async getComments(options) {
        const { objectId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/comment/object/${encodeURIComponent(objectId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IconGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Load a single icon by id
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon__id__get
     * @param options Request options.
     */
    async getIcon(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/icon/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get all existing global icons
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_global_get
     * @param options Request options.
     */
    async getGlobalIcons(options) {
        const { headers, errorStrategy } = options ?? {};
        const request = new Request('GET', '/rest/assets/latest/icon/global', constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Fetch all configured icons from the object schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_objectschema__objectschemaid__get
     * @param options Request options.
     */
    async getIconsBySchema(options) {
        const { objectSchemaId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/icon/objectschema/${encodeURIComponent(objectSchemaId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ImportGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Start import
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#import_start__id__post
     * @param options Request options.
     */
    async startImport(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/assets/latest/import/start/${encodeURIComponent(id)}`, constructHeaders({}, headers), JSON.stringify({}));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IndexGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Handle the indexing of Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_start_post
     * @param options Request options.
     */
    async startReindex(options) {
        const { clean, headers, errorStrategy } = options ?? {};
        const queryParams = { clean };
        const request = new Request('POST', constructUrl('/rest/assets/latest/index/reindex/start', queryParams), constructHeaders(null, headers), null);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Only applicable in a Data Center environment. Resource to start a re-index of the current node. This reindex will not clean the entire cluster just refresh the objects in cache on the current data center node
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_currentnode_post
     * @param options Request options.
     */
    async startCurrentModeReindex(options) {
        const { headers, errorStrategy } = options ?? {};
        const request = new Request('POST', '/rest/assets/latest/index/reindex/currentnode', constructHeaders(null, headers), null);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AqlGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#aql_objects_get
     * @param options Request options.
     */
    async getObjects(options) {
        const { qlQuery, page, resultPerPage, includeAttributes, includeAttributesDeep, includeTypeAttributes, includeExtendedInfo, headers, errorStrategy } = options ?? {};
        const queryParams = { qlQuery, page, resultPerPage, includeAttributes, includeAttributesDeep, includeTypeAttributes, includeExtendedInfo };
        const request = new Request('GET', constructUrl('/rest/assets/latest/aql/objects', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProgressGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Show ongoing Assets processes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_assets_reindex_reindex_get
     * @param options Request options.
     */
    async getReindexProgress(options) {
        const { headers, errorStrategy } = options ?? {};
        const request = new Request('GET', '/rest/assets/latest/progress/category/assets-reindex/reindex', constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get progress for import source
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_imports__id__get
     * @param options Request options.
     */
    async getImportProgress(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/progress/category/imports/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class QRCodeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get QR code for object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#qrcode_object__objectid__code_png_get
     * @param options Request options.
     */
    async getQrCode(options) {
        const { objectId, size, headers, errorStrategy } = options;
        const queryParams = { size };
        const request = new Request('GET', constructUrl(`/rest/assets/latest/qrcode/object/${encodeURIComponent(objectId)}/code.png`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ConfigGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get the Assets statuses
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_get
     * @param options Request options.
     */
    async getConfigStatuses(options) {
        const { objectSchemaId, headers, errorStrategy } = options;
        const queryParams = { objectSchemaId };
        const request = new Request('GET', constructUrl('/rest/assets/latest/config/statustype', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_post
     * @param options Request options.
     */
    async createConfigStatus(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/assets/latest/config/statustype', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__get
     * @param options Request options.
     */
    async getConfigStatus(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/config/statustype/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__put
     * @param options Request options.
     */
    async updateConfigStatus(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/assets/latest/config/statustype/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Delete status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__delete
     * @param options Request options.
     */
    async deleteConfigStatus(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/assets/latest/config/statustype/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ObjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attribute = new ObjectAttributeGroup(implementation, this.getGlobalErrorStrategy);
        this.History = new ObjectHistoryGroup(implementation, this.getGlobalErrorStrategy);
        this.Reference = new ObjectReferenceGroup(implementation, this.getGlobalErrorStrategy);
        this.Ticket = new ObjectTicketGroup(implementation, this.getGlobalErrorStrategy);
        this.Schema = new ObjectSchemaGroup(implementation, this.getGlobalErrorStrategy);
        this.Type = new ObjectTypeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Load one object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__get
     * @param options Request options.
     */
    async getObject(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/object/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an existing object in Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__put
     * @param options Request options.
     */
    async updateObject(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/assets/latest/object/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete the referenced object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__delete
     * @param options Request options.
     */
    async deleteObject(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/assets/latest/object/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Create a new object in Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_create_post
     * @param options Request options.
     */
    async createObject(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/assets/latest/object/create', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a list of objects based on an AQL.
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_navlist_aql_post
     * @param options Request options.
     */
    async getObjectsWithAql(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/assets/latest/object/navlist/aql', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectAttributeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * List all attributes for the given object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__attributes_get
     * @param options Request options.
     */
    async getAttributes(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/object/${encodeURIComponent(id)}/attributes`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a new attribute for a given attribute.
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute_create_post
     * @param options Request options.
     */
    async createAttribute(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/assets/latest/objectattribute/create', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an already existing object attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__put
     * @param options Request options.
     */
    async updateAttribute(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/assets/latest/objectattribute/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Load a single object attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__get
     * @param options Request options.
     */
    async getAttribute(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/objectattribute/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectHistoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Retrieve the history entries for this object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__history_get
     * @param options Request options.
     */
    async getHistory(options) {
        const { id, asc, abbreviate, headers, errorStrategy } = options;
        const queryParams = { asc, abbreviate };
        const request = new Request('GET', constructUrl(`/rest/assets/latest/object/${encodeURIComponent(id)}/history`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectReferenceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find all references for an object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__referenceinfo_get
     * @param options Request options.
     */
    async getReferences(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/object/${encodeURIComponent(id)}/referenceinfo`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectTicketGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Relation between Jira issues and Assets objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectconnectedtickets__objectid__get
     * @param options Request options.
     */
    async getConnectedTickets(options) {
        const { objectId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/objectconnectedtickets/${encodeURIComponent(objectId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectSchemaGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Resource to find object schemas in Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_list_get
     * @param options Request options.
     */
    async getSchemas(options) {
        const { headers, errorStrategy } = options ?? {};
        const request = new Request('GET', '/rest/assets/latest/objectschema/list', constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_create_post
     * @param options Request options.
     */
    async createSchema(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/assets/latest/objectschema/create', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__put
     * @param options Request options.
     */
    async updateSchema(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/assets/latest/objectschema/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__get
     * @param options Request options.
     */
    async getSchema(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/objectschema/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__delete
     * @param options Request options.
     */
    async deleteSchema(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/assets/latest/objectschema/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Find all object type attributes for this object schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__attributes_get
     * @param options Request options.
     */
    async getSchemaObjectTypeAttributes(options) {
        const { id, onlyValueEditable, extended, query, headers, errorStrategy } = options;
        const queryParams = { onlyValueEditable, extended, query };
        const request = new Request('GET', constructUrl(`/rest/assets/latest/objectschema/${encodeURIComponent(id)}/attributes`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Find all object types for this object schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__objecttypes_flat_get
     * @param options Request options.
     */
    async getSchemaObjectTypes(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/objectschema/${encodeURIComponent(id)}/objecttypes/flat`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attribute = new ObjectTypeAttributeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Resource to get object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__get
     * @param options Request options.
     */
    async getType(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/assets/latest/objecttype/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__put
     * @param options Request options.
     */
    async updateType(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/assets/latest/objecttype/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete the object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__delete
     * @param options Request options.
     */
    async deleteType(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/assets/latest/objecttype/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Find all object type attribute for this object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__attributes_get
     * @param options Request options.
     */
    async getTypeAttributes(options) {
        const { id, onlyValueEditable, orderByName, query, includeValuesExist, excludeParentAttributes, includeChildren, orderByRequired, headers, errorStrategy } = options;
        const queryParams = { onlyValueEditable, orderByName, query, includeValuesExist, excludeParentAttributes, includeChildren, orderByRequired };
        const request = new Request('GET', constructUrl(`/rest/assets/latest/objecttype/${encodeURIComponent(id)}/attributes`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Change position of this object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__position_post
     * @param options Request options.
     */
    async changeTypePosition(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/assets/latest/objecttype/${encodeURIComponent(id)}/position`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype_create_post
     * @param options Request options.
     */
    async createType(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/assets/latest/objecttype/create', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectTypeAttributeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Create object type attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid__post
     * @param options Request options.
     */
    async createAttribute(options) {
        const { objectTypeId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/assets/latest/objecttypeattribute/${encodeURIComponent(objectTypeId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update object type attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid___id__put
     * @param options Request options.
     */
    async updateAttribute(options) {
        const { objectTypeId, id, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/assets/latest/objecttypeattribute/${encodeURIComponent(objectTypeId)}/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete object type attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__id__delete
     * @param options Request options.
     */
    async deleteAttribute(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/assets/latest/objecttypeattribute/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
